==> glslGallery-0.0.3.tgz: package/src/js/glslGallery.js <==
/*
The MIT License (MIT)

Copyright (c) 2016 Patricio Gonzalez Vivo ( http://www.patriciogonzalezvivo.com )

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the 'Software'), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

import GalleryItem from 'app/core/GalleryItem';

export default class GlslGallery {
    constructor (selector, options) {
        if (typeof selector === 'object' && selector.nodeType && selector.nodeType === 1) {
            this.container = selector;
        }
        else if (typeof selector === 'string') {
            this.container = document.querySelector(selector);
        }
        else {
            console.log('Error, type ' + typeof selector + ' of ' + selector + ' is unknown');
            return;
        }

        this.options = options || {};

        if (!this.options.showAuthor) {
            this.options.showAuthor = true;
        }

        if (!this.options.showTitle) {
            this.options.showTitle = true;
        }

        if (!this.options.hoverPreview) {
            this.options.hoverPreview = true;
        }

        if (!this.options.openFrameIcon) {
            this.options.openFrameIcon = true;
        }

        if (!this.options.clickRun) {
            this.options.clickRun = 'player';
        }

        this.items = [];

        if (selector.hasAttribute('data-properties')) {
            let prop = selector.getAttribute('data-properties').split(',');
            for (let i in prop) {
                let values = prop[i].split(':');
                if (values.length === 1) {
                    this.options[values[0]] = true;
                }
                else if (values.length === 2) {
                    this.options[values[0]] = (values[1] === 'true' || values[1] === 'false') ? (values[1] === 'true') : values[1];
                }
            }
        }

        if (selector.hasAttribute('data')) {
            let data = selector.getAttribute('data').split(',');
            for (let i in data) {
                this.items.push(new GalleryItem(data[i], this, this.options));
            }
        }

        return this;
    }

    version() {
        return '0.0.1';
    }
}

function glslGalleryLoadAll() {
    if (!window.GlslGallery) {
        window.GlslGallery = GlslGallery;
    }

    var list = document.getElementsByClassName('glslGallery');
    if (list.length > 0) {
        window.glslGalleries = [];
        for (var i = 0; i < list.length; i++) {
            var gallery = new GlslGallery(list[i]);
            window.glslGalleries.push(gallery);
        }
    }
}

window.onload = function () {
    glslGalleryLoadAll();
};

==> glslGallery-0.0.5.tgz: package/src/js/glslGallery.js <==
/*
The MIT License (MIT)

Copyright (c) 2016 Patricio Gonzalez Vivo ( http://www.patriciogonzalezvivo.com )

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the 'Software'), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

import GalleryItem from 'app/core/GalleryItem';

export default class GlslGallery {
    constructor (selector, options) {
        if (typeof selector === 'object' && selector.nodeType && selector.nodeType === 1) {
            this.container = selector;
        }
        else if (typeof selector === 'string') {
            this.container = document.querySelector(selector);
        }
        else {
            console.log('Error, type ' + typeof selector + ' of ' + selector + ' is unknown');
            return;
        }

        this.options = options || {};

        if (!this.options.showAuthor) {
            this.options.showAuthor = true;
        }

        if (!this.options.showTitle) {
            this.options.showTitle = true;
        }

        if (!this.options.hoverPreview) {
            this.options.hoverPreview = true;
        }

        if (!this.options.openFrameIcon) {
            this.options.openFrameIcon = true;
        }

        if (!this.options.clickRun) {
            this.options.clickRun = 'player';
        }

        this.items = [];

        if (selector.hasAttribute('data-properties')) {
            let prop = selector.getAttribute('data-properties').split(',');
            for (let i in prop) {
                let values = prop[i].split(':');
                if (values.length === 1) {
                    this.options[values[0]] = true;
                }
                else if (values.length === 2) {
                    this.options[values[0]] = (values[1] === 'true' || values[1] === 'false') ? (values[1] === 'true') : values[1];
                }
            }
        }

        if (selector.hasAttribute('data')) {
            this.addItems(selector.getAttribute('data'));
        }

        if (this.options.logs) {
            this.addItems(this.options.logs);
        }

        return this;
    }

    addItem (log) {
        if (typeof log === 'number') {
            log = log.toString();
        }
        this.items.push(new GalleryItem(log, this, this.options));
    }

    addItems (logs) {
        if (typeof logs === 'string') {
            logs = logs.split(',');
        }
        for (let i in logs) {
            this.addItem(logs[i]);
        }
    }

    version() {
        return '0.0.5';
    }
}

function glslGalleryLoadAll() {
    if (!window.GlslGallery) {
        window.GlslGallery = GlslGallery;
    }

    var list = document.getElementsByClassName('glslGallery');
    if (list.length > 0) {
        window.glslGalleries = [];
        for (var i = 0; i < list.length; i++) {
            var gallery = new GlslGallery(list[i]);
            window.glslGalleries.push(gallery);
        }
    }
}

window.addEventListener('load', function () {
    glslGalleryLoadAll();
});
